<?php

/**
Plugin Name: Eventpeak.com channels
Plugin URI: https://eventpeak.com
Version: 1.0.5
Author: Scoopexpert BV
Author uri: https://scoopexpert.com
Description: Embed Eventpeak channels with events and activities to your Wordpress website
!@Text Domain!@: eventpeak
!@Domain Path!@: /languages
 */

/*
 * Copyright 2016-2018 Scoopexpert BV
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * ( at your option ) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // don't access directly
};

add_shortcode("eventpeak_show_channel", "epShowChannel");

function epShowChannel($atts) {
		$atts = shortcode_atts( array(
		'cssclass' => "",
		'channel' => "0",
		'components' => "search,map,cards",
		'eventstart' => "",
		'eventend' => "",
		'daterangedays' => "7",
		'width' => "100%",
		'height' => "1300px"
	), $atts, 'eventpeak_show_channel' );
	wp_enqueue_script('epwidget', 'https://cdn.eventpeak.com/assets/js/ep_widget.js');
	$options = get_option( 'eventpeak_options' );

    return '<style type="text/css">'.$options['eventpeak_field_customcss' ].'</style><div class="eventpeak-widget" components="'.$atts["components"].'" cssclass="'.$atts["cssclass"].'" channel="'.$atts["channel"].'" eventstart="'.$atts["eventstart"].'" eventend="'.$atts["eventend"].'" daterangedays="'.$atts["daterangedays"].'" daterange="daysinfuture" width="'.$atts["width"].'" height="'.$atts["height"].'"></div>';
}


function eventpeak_settings_init() {
 // register a new setting for "eventpeak" page
 register_setting( 'eventpeak', 'eventpeak_options' );
 
 // register a new section in the "eventpeak" page
 add_settings_section(
 'eventpeak_section_developers',
 __( 'Welcome to Eventpeak', 'eventpeak' ),
 'eventpeak_section_developers_cb',
 'eventpeak'
 );
 
 // register a new field in the "eventpeak_section_developers" section, inside the "eventpeak" page
 add_settings_field(
 'eventpeak_field_customcss', // as of WP 4.6 this value is used only internally
 // use $args' label_for to populate the id inside the callback
 __( 'Custom CSS code', 'eventpeak' ),
 'eventpeak_field_customcss_cb',
 'eventpeak',
 'eventpeak_section_developers',
 [
 'label_for' => 'eventpeak_field_customcss',
 'class' => 'eventpeak_row',
 'eventpeak_custom_css' => 'customcss',
 ]
 );
}
 
/**
 * register our eventpeak_settings_init to the admin_init action hook
 */
add_action( 'admin_init', 'eventpeak_settings_init' );
 
/**
 * custom option and settings:
 * callback functions
 */
 
// developers section cb
 
// section callbacks can accept an $args parameter, which is an array.
// $args have the following keys defined: title, id, callback.
// the values are defined at the add_settings_section() function.
function eventpeak_section_developers_cb( $args ) {
 ?>
 <p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( 'Please enter custom css code', 'eventpeak' ); ?></p>
 <?php
}
 
// pill field cb
 
// field callbacks can accept an $args parameter, which is an array.
// $args is defined at the add_settings_field() function.
// wordpress has magic interaction with the following keys: label_for, class.
// the "label_for" key value is used for the "for" attribute of the <label>.
// the "class" key value is used for the "class" attribute of the <tr> containing the field.
// you can add custom key value pairs to be used inside your callbacks.
function eventpeak_field_customcss_cb( $args ) {
 // get the value of the setting we've registered with register_setting()
 $options = get_option( 'eventpeak_options' );
 // output the field
 ?>
 <textarea style="width: 100%;height: 200px;" id="<?php echo esc_attr( $args['label_for'] ); ?>"
 data-custom="<?php echo esc_attr( $args['eventpeak_custom_css'] ); ?>"
 name="eventpeak_options[<?php echo esc_attr( $args['label_for'] ); ?>]"
 ><?=$options[ $args['label_for'] ]?></textarea>
 <p class="description">
 <?php esc_html_e( 'Enter any custom css code which will be added to you channel widget to customize. Keep in mind that you can separate widgets by "cssclass" parameter of the shortcode on a page', 'eventpeak' ); ?>
 </p>
 <?php
}
 
/**
 * top level menu
 */
function eventpeak_options_page() {
 // add top level menu page
 add_menu_page(
 'Eventpeak Options',
 'Eventpeak',
 'manage_options',
 'eventpeak',
 'eventpeak_options_page_html'
 );
}
 
/**
 * register our eventpeak_options_page to the admin_menu action hook
 */
add_action( 'admin_menu', 'eventpeak_options_page' );
 
/**
 * top level menu:
 * callback functions
 */
function eventpeak_options_page_html() {
 // check user capabilities
 if ( ! current_user_can( 'manage_options' ) ) {
 return;
 }
 
 // add error/update messages
 
 // check if the user have submitted the settings
 // wordpress will add the "settings-updated" $_GET parameter to the url
 if ( isset( $_GET['settings-updated'] ) ) {
 // add settings saved message with the class of "updated"
 add_settings_error( 'eventpeak_messages', 'eventpeak_message', __( 'Settings Saved', 'eventpeak' ), 'updated' );
 }
 
 // show error/update messages
 settings_errors( 'eventpeak_messages' );
 ?>
 <div class="wrap">
 <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
 <form action="options.php" method="post">
 <?php
 // output security fields for the registered setting "eventpeak"
 settings_fields( 'eventpeak' );
 // output setting sections and their fields
 // (sections are registered for "eventpeak", each field is registered to a specific section)
 do_settings_sections( 'eventpeak' );
 // output save settings button
 submit_button( 'Save Settings' );
 ?>
 </form>
 </div>
 <?php
}